Stan Math Library: stan/math/prim/scal/fun/log_diff_exp.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_diff_exp.hpp File Reference
`#include <stan/math/prim/scal/fun/log1m_exp.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <boost/throw_exception.hpp>`
`#include <limits>`
`#include <stdexcept>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 >
boost::math::tools::promote_args< T1, T2 >::type | stan::math::log_diff_exp (const T1 x, const T2 y)
| The natural logarithm of the difference of the natural exponentiation of x1 and the natural exponentiation of x2. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.